@@ -57,7 +57,7 @@ ManualSelectFilterPage::ManualSelectFilterPage(QWidget *parent)
     mWidget = new Ui::ManualSelectFilterPage;
     mWidget->setupUi(this);
     mWidget->mIntroSidebar->setPixmap(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("importwizard/pics/step1.png")));
-    connect(mWidget->mFilterCombo, QOverload<int>::of(&KComboBox::activated), this, &ManualSelectFilterPage::filterSelected);
+    connect(mWidget->mFilterCombo, QOverload<int>::of(&QComboBox::activated), this, &ManualSelectFilterPage::filterSelected);
 
     addFilter(new MailImporter::FilterKMailArchive);
     addFilter(new MailImporter::FilterMBox);
